import en from 'vuetify/lib/locale/en';
import ar from 'vuetify/lib/locale/ar';

export default {
  // Disable server-side rendering: https://go.nuxtjs.dev/ssr-mode
  ssr: false,
  target: 'static',
  server: {
    port: 6060 // default: 3000
  },
  // Global page headers: https://go.nuxtjs.dev/config-head
  head: {
    titleTemplate: '%s - digital-marketing',
    title: 'digital-marketing',
    htmlAttrs: {
      lang: process.env.VUE_APP_defualtLanguage
    },

    meta: [
      {
        charset: 'utf-8'
      },
      {
        name: 'viewport',
        content: 'width=device-width, initial-scale=1'
      },
      {
        hid: 'description',
        name: 'description',
        content: ''
      },
      {
        name: 'format-detection',
        content: 'telephone=no'
      },
      {
        'http-equiv': 'Content-Security-Policy',
        content: "default-src * 'unsafe-inline' 'unsafe-eval' data:  https: blob: 'self'"
      }
    ],
    link: [
      {
        rel: 'icon',
        type: 'image/x-icon',
        href: '/favicon.ico'
      },
      {
        rel: 'stylesheet',
        href: 'https://fonts.googleapis.com/css2?family=Poppins:wght@100;300;400;500;600;700&display=swap'
      },
      {
        rel: 'stylesheet',
        href: 'https://fonts.googleapis.com/css2?family=Cairo:wght@300;400;500;700&display=swap'
      },
      {
        rel: 'stylesheet',
        href: 'https://fonts.googleapis.com/css2?family=Inter:wght@300;400;500;700&display=swap'
      },
      {
        rel: 'stylesheet',
        href: 'https://cdn.jsdelivr.net/npm/bootstrap@5.0.2/dist/css/bootstrap.min.css',
        integrity: 'sha384-EVSTQN3/azprG1Anm3QDgpJLIm9Nao0Yz1ztcQTwFspd3yD65VohhpuuCOmLASjC',
        crossorigin: 'anonymous'
      }
    ],
    script: [
      {
        // Adding Clarity script
        innerHTML: `(function(c,l,a,r,i,t,y){
          c[a]=c[a]||function(){(c[a].q=c[a].q||[]).push(arguments)};
          t=l.createElement(r);t.async=1;t.src="https://www.clarity.ms/tag/"+i;
          y=l.getElementsByTagName(r)[0];y.parentNode.insertBefore(t,y);
        })(window, document, "clarity", "script", "lgq2en7ad0");`
      },
      {
        src: 'https://cdn.jsdelivr.net/npm/bootstrap@5.0.2/dist/js/bootstrap.bundle.min.js',
        integrity: 'sha384-MrcW6ZMFYlzcLA8Nl+NtUVF0sA7MsXsP1UyJoMp4YLEuNSfAP+JcXn/tWtIaxVXM',
        crossorigin: 'anonymous'
      },
      {
        src: '/js/fb-sdk.js'
      },
      {
        src: 'https://cdn.jsdelivr.net/npm/pdfjs-dist@2.7.570/build/pdf.min.js'
      }
    ]
  },

  // Global CSS: https://go.nuxtjs.dev/config-css
  css: [ '~/style/swiper.css', '~/style/main.scss' ],
  plugins: [
    {
      src: '~/mixin/index'
    },
    {
      src: '~/plugins/notify',
      ssr: false
    },
    // {
    //   src: '~/plugins/swiper',
    //   ssr: false
    // },
    {
      src: '~/plugins/axios'
    },
    {
      src: '~/plugins/Api',
      ssr: false
    },
    {
      src: '~/plugins/vee-validate',
      ssr: false
    },
    {
      src: '~/plugins/langs',
      ssr: false
    },
    {
      src: '~/plugins/alert',
      ssr: false
    },
    {
      src: '~/plugins/Formbuilder',
      ssr: false
    },
    {
      src: '~/plugins/chart',
      ssr: false
    },
    {
      src: '~/plugins/editor',
      mode: 'client'
    },
    {
      src: '~/plugins/dompurify',
      mode: 'client'
    },
    {
      src: '~/plugins/utils',
      mode: 'client'
    }
  ],
  loading: {
    color: '#FFCB04',
    height: '4px'
  },
  // Auto import components: https://go.nuxtjs.dev/config-components
  components: true, //['@/components', '@/components/utils', '@/components/custome', '@/components/charts', '@/components/pages'],

  // Modules for dev and build (recommended): https://go.nuxtjs.dev/config-modules
  buildModules: [
    '@nuxtjs/vuetify',
    '@nuxtjs/moment',
    // 'nuxt-vite',
    '@nuxtjs/laravel-echo'
  ],
  vite: {
    ssr: false, // enable unstable server-side rendering for development (false by default)
    // experimentWarning: false // hide experimental warning message (disabled by default for tests)
    vue: {
      /* options for vite-plugin-vue2 */
    },
    server: {
      hmr: {
        overlay: false
      }
    }
  },
  router: {
    middleware: [ 'auth' ]
  },

  render: {
    csp: {
      reportOnly: true,
      hashAlgorithm: 'sha256',
      unsafeInlineCompatiblity: true,
      policies: {
        'default-src': [ "* 'self'", "'unsafe-inline'", 'https:', 'data:', 'blob:' ],
        'script-src': [ " * 'self'", "'unsafe-inline'", "'unsafe-eval'" ],
        'style-src': [ " * 'self'", "'unsafe-inline'" ],
        'img-src': [ "* 'self'", 'https:', 'data:', 'blob:' ],
        'font-src': [ "* 'self'", 'data:' ],
        'connect-src': [ "* 'self'", 'wss', 'ws' ],
        'object-src': [ "* 'self'", ' blob:', 'data:' ],
        'media-src': [ "'* 'self'", 'blob:', 'data:' ]
      }
    }
  },

  modules: [
    // https://go.nuxtjs.dev/axios
    '@nuxtjs/axios',
    '@nuxtjs/i18n',
    '@nuxtjs/tailwindcss',
    '@nuxtjs/auth-next',
    'nuxt-svg-loader'
  ],

  tailwindcss: {
    configPath: 'tailwind.config.js',
    cssPath: '~/style/tailwind.css'
  },
  auth: {
    strategies: {
      local: {
        token: {
          property: 'data.token',
          global: true,
          maxAge: 6000000
        },
        refreshToken: {
          maxAge: 20160 * 60
        },
        endpoints: {
          login: {
            url: '/auth/login',
            method: 'post'
          },
          user: false,
          logout: false
        }
      }
    },
    // cookie: {
    //   prefix: 'data.',
    //   options: {
    //     path: '/'
    //   }
    // },
    redirect: {
      login: '/',
      logout: '/',
      callback: '/',
      registration: 'auth/registration',
      home: '/dashboard'
    }
  },
  // https://i18n.nuxtjs.org/setup
  i18n: {
    strategy: 'no_prefix',
    locales: [
      {
        code: 'en',
        name: 'English',
        dir: 'ltr',
        file: 'en.js',
        iso: 'en-US'
      },
      {
        code: 'ar',
        name: 'Arabic',
        dir: 'rtl',
        file: 'ar.js',
        iso: 'ar-AR'
      }
    ],
    lazy: true,
    langDir: 'lang/',
    defaultLocale: process.env.VUE_APP_defualtLanguage,
    vueI18n: {
      fallbackLocale: process.env.VUE_APP_defualtLanguage,
      silentTranslationWarn: true
    },
    loadLanguagesAsync: true,
    detectBrowserLanguage: {
      useCookie: true,
      cookieKey: 'redirected',
      alwaysRedirect: true,
      fallbackLocale: process.env.VUE_APP_defualtLanguage
    },
    vueI18nLoader: true
  },

  // Axios module configuration: https://go.nuxtjs.dev/config-axios
  axios: {
    // Workaround to avoid enforcing hard-coded localhost:3000: https://github.com/nuxt-community/axios-module/issues/308
    baseURL: process.env.VUE_APP_API_URL
    // baseURL: 'https://development.thestring.net/api/v1'
  },
  // Vuetify module configuration: https://go.nuxtjs.dev/config-vuetify
  vuetify: {
    lang: {
      locales: {
        ar,
        en
      },
      current: process.env.VUE_APP_defualtLanguage
    },
    // customVariables: [ '@/style/variables.scss' ],
    treeShake: true,
    theme: {
      options: {
        customProperties: true
      },
      dark: false,
      themes: {
        light: {
          primary: '#001556',
          accent: '#FFCB04',
          accentlight: '#FFFAE6',
          subtitle: '#969BA0',
          danger: '#F24242',
          lighty: '#e9ecff',
          grayPage: '#F9FAFB'
        }
      }
    }
  },

  // Build Configuration: https://go.nuxtjs.dev/config-build
  build: {
    loaders: {
      scss: {
        sourceMap: false
      }
    }
  },
  env: {
    TINYMCE_API_KEY: process.env.TINYMCE_API_KEY,
    VUE_APP_SOCKET_KEY: process.env.VUE_APP_SOCKET_KEY,
    VUE_APP_SOCKET_HOST: process.env.VUE_APP_SOCKET_HOST
  },
  devServerHandlers: []
};
