/**
 *
 * @param method
 * @param uri
 * @param payload
 * @param successCallback
 * @param failCallback
 * @param isURL
 * @returns {Promise<void>}
 */

export default (context, inject) => {
  const apiCall = async function Api(
    method = 'get',
    uri,
    payload = null,
    successCallback = null,
    failCallback = null,
    isShowLoader = true,
    isShowSuccessAlert = true
  ) {
    if (!uri.includes('send-message') && isShowLoader) context.store.commit('utils/load', true)
    try {
      const response = await this.$axios[method](uri, payload)
      if (isShowSuccessAlert && response.data.message && method !== 'get' && !uri.includes('send-message')) {
        this.$alert('success', response.data.message)
      }
      if (successCallback) {
        successCallback(response)
      }
    } catch (error) {
      context.store.commit('utils/load', false)
      if (error?.response?.status == 401) {
        localStorage.clear()
        this.$router.push('/')
      }
      if (error?.response?.data?.message) {
        this.$alert('error', error.response.data.message)
      }
      if (failCallback) {
        failCallback(error.response)
      }
    } finally {
      context.store.commit('utils/load', false)
    }
  }
  // Inject $hello(msg) in Vue, context and store.
  inject('Api', apiCall)
  // For Nuxt <= 2.12, also add 👇
  context.$Api = apiCall
}
