import Vue from 'vue';
import {
  ValidationProvider,
  ValidationObserver,
  extend,
} from 'vee-validate';
import * as rules from 'vee-validate/dist/rules';

export default async (context) => {
  Object.keys(rules).forEach(rule => {
    extend(rule, {
      ...rules[rule], // copies rule configuration
      message: context.app.i18n.t(`validations.messages.${rule}`) // assign message
    });
  });

  extend("float", {
    validate: (value, {
      decimals = '*',
      separator = '.'
    } = {}) => {
      if (value === null || value === undefined || value === '') {
        return {
          valid: false
        };
      }
      if (Number(decimals) === 0) {
        return {
          valid: /^-?\d*$/.test(value),
        };
      }
      const regexPart = decimals === '*' ? '+' : `{1,${decimals}}`;
      const regex = new RegExp(`^[-+]?\\d*(\\${separator}\\d${regexPart})?([eE]{1}[-]?\\d+)?$`);

      return {
        valid: regex.test(value),
      };
    },
    message: 'The {_field_} field must contain only decimal values'
  })

  Vue.component('v-observer', ValidationObserver);
  Vue.component('v-validate', ValidationProvider);

}
