// state
import Echo from 'laravel-echo'

const state = () => ({
  load: false,
  data: null,
  check: true,
  token: localStorage.getItem('token') ? localStorage.getItem('token') : null,
  user:
    localStorage.getItem('authed_user') && localStorage.getItem('authed_user') !== 'undefined'
      ? JSON.parse(localStorage.getItem('authed_user'))
      : null
})

// getters
const getters = {
  userData(state) {
    return state.user
  }
}

// actions
const actions = {
  user(context, payload) {
    context.commit('fetchUser')
  },
  login($this, payload) {
    $this.commit('loginUser', payload)
  },
  logout($this) {
    $this.commit('logout')
  },
  initEcho($this) {
    $this.commit('initEcho')
  }
}

// mutations
const mutations = {
  loginUser(state, payload) {
    this.$auth
      .loginWith('local', {
        data: payload
      })
      .then(res => {
        localStorage.removeItem('authed_user')
        state.data = res
        state.load = false
        state.check = true
        state.token = res.data.data.token
        localStorage.setItem('token', res.data.data.token)
        this.$router.push('/dashboard')
        //todo: remove this and replace it with one function
        this.$Api(
          'get',
          '/admin/profile',
          null,
          res => {
            state.load = false
            state.user = res.data.data
            localStorage.setItem('authed_user', JSON.stringify(res.data.data))
            this.$auth.setUser(res.data.data)
          },
          err => {
            state.load = false
            console.log(err)
          }
        )
      })
      .catch(error => {
        if (error.response?.data?.message) {
          this.$alert('error', error.response.data.message)
        }
      })
  },
  fetchUser(state) {
    state.load = true
    this.$Api(
      'get',
      '/admin/profile',
      null,
      res => {
        state.load = false
        state.user = res.data.data
        localStorage.setItem('authed_user', JSON.stringify(res.data.data))
        this.$auth.setUser(res.data.data)
      },
      err => {
        state.load = false
        console.log(err)
      }
    )
  },
  logout() {
    localStorage.clear()
    this.$router.push('/')
  },

  initEcho(state) {
    window.Pusher = require('pusher-js')

    const domain = localStorage.getItem('domain')
    const token = state.token

    if (domain && token) {
      window.Echo = new Echo({
        broadcaster: 'pusher',
        key: process.env.VUE_APP_SOCKET_KEY,
        cluster: 'mt1',
        wsHost: process.env.VUE_APP_SOCKET_HOST,
        authEndpoint: `${domain.slice(0, -7)}/broadcasting/auth`,
        wsPort: 80,
        wssPort: 443,
        disableStats: true,
        enabledTransports: ['ws', 'wss'],
        auth: {
          headers: {
            Accept: 'application/json',
            Authorization: `Bearer ${token}`
          }
        }
      })
    }
  }
}

export default {
  namespaced: true,
  state,
  getters,
  actions,
  mutations
}
