const defaultCampaign = {
  type: '',
  name: '',
  segments: [],
  tags: [],
  content: null,
  template_id: null,
  sender_data: {
    subject: '',
    sender_name: '',
    from_email: '',
    email_identity_id: 5275207
  }
};



export const state = () => ({
  segments: [],
  campaigns: [],
  metaData: {},
  campaign: defaultCampaign,
  schedule: {
    type: 'schedule',
    date: '',
    time: '',
  },
});


export const mutations = {
  SET_CAMPAIGNS (state, campaigns) {
    state.campaigns = campaigns;
  },
  SET_CAMPAIGN (state, campaign) {
    state.campaign = campaign;
  },
  UPDATE_SENDER_DATA (state, sender_data) {
    state.campaign.sender_data = sender_data;
  },
  SET_SEGMENTS (state, segments) {
    state.segments = segments;
  },
  SET_TEMPLATE (state, template) {
    state.campaign.template_id = template.id;
    localStorage.setItem('template', JSON.stringify(template));
  },
  CLEAR_CAMPAIGN (state) {
    state.campaign = defaultCampaign;
    state.schedule = {
      type: 'schedule',
      date: '',
      time: '',
    };
    localStorage.removeItem('template');
    localStorage.removeItem('content');
  }
};

export const actions = {
  async getSegments ({ commit, }) {
    const {
      data: { data }
    } = await this.$axios.get('admin/segments-list');
    commit('SET_SEGMENTS', data);
  },
  async getCampaigns ({ commit }, filters) {
    const {
      data: { data }
    } = await this.$axios.get(`admin/campaigns`, { params: filters });
    commit('SET_CAMPAIGNS', data);
    return data;
  },
  async getCampaign ({ commit }, id) {
    const {
      data: { data }
    } = await this.$axios.get(`admin/campaigns/${ id }`);
    const content = JSON.parse(localStorage.getItem('content'));
    const templateId = JSON.parse(localStorage.getItem('template'))?.id;
    if (!data.content && content) data.content = content;
    if (!data.template_id && templateId) data.template_id = templateId;
    commit('SET_CAMPAIGN', data);
  },
  async createCampaign ({ commit }, campaign) {
    const {
      data: { data }
    } = await this.$axios.post(`admin/campaigns/typeInformationStep`, campaign);
    return data;
  },
  async updateCampaign ({ commit }, campaign) {
    const { data: { data } } = await this.$axios.post(`admin/campaigns/${ campaign.id }/contentStep`, campaign.sender_data);
    commit('UPDATE_SENDER_DATA', data.sender_data);
  },
  async sendCampaign ({ state },
    type = 'schedule',
  ) {
    const template_id = state.campaign.template_id;
    const payload = {
      content: state.campaign.content,
      type,
    };
    if (template_id) {
      payload.template_id = template_id;
      delete payload.content;
    }
    if (type === 'schedule') {
      payload.date = state.schedule.date;
      payload.time = state.schedule.time;
    }
    try {
      const { data } = await this.$axios.post(`admin/campaigns/${ state.campaign.id }/sendStep`, payload);
      return data;
    }
    catch (e) {
      console.log(e);
      throw e;
    }

  },

};

export const getters = {
  groups: state => state.groups,
  tags: state => state.tags,
  campaigns: state => state.campaigns,
  metaData: state => state.metaData,
  campaign: state => state.campaign,
};
