export const state = () => ({
  contactsLoader: false,
  sending: false,
  conversationLoader: false,
  conversation: {},
  contacts: null
})

export const actions = {
  newConversation($this, payload) {
    $this.commit('openNewChat', payload)
  },
  getMessagesWhatsApp($this, payload) {
    $this.commit('getMessages', payload)
  },
  sendMessageWhatsApp($this, payload) {
    $this.commit('sendNewMessages', payload)
  },
  contacts($this, payload) {
    $this.commit('fetchUserContacts', payload)
  },
  assignList($this, payload) {
    $this.commit('fetchAssignList', payload)
  },
  assignToAgent($this, payload) {
    $this.commit('assignToAgent', payload)
  },
  addToArchive($this, payload) {
    $this.commit('addToArchive', payload)
  }
}

export const mutations = {
  openNewChat(state, payload) {
    state.conversationLoader = true
    state.conversation.user = payload
    state.conversation.messages = []
    state.conversationLoader = false
  },
  sendNewMessages(state, payload) {
    state.sending = true
    this.$Api(
      'post',
      `/whatsapp/accounts/${payload.whatapp_account}/conversations/${payload.userId}/messages/send-message`,
      payload.payload,
      res => {
        state.sending = false
        payload.callback()
      },
      err => {
        state.sending = false
        console.log(err)
      }
    )
  },
  assignToAgent(state, payload) {
    state.sending = true
    this.$Api(
      'post',
      `/whatsapp/accounts/${payload.whatapp_account}/conversations/${payload.userId}/assign-to-agent`,
      payload.payload,
      res => {
        state.sending = false
        payload.callback()
      },
      err => {
        state.sending = false
        console.log(err)
      }
    )
  },
  getMessages(state, payload) {
    state.conversationLoader = true
    this.$Api(
      'get',
      `/whatsapp/accounts/${payload.whatapp_account}/conversations/${payload.userId}/messages?page=${payload.page}`,
      null,
      res => {
        payload.callback(res)
      },
      err => {
        state.conversationLoader = false
        console.log(err)
      }
    )
  },
  fetchAssignList(state, payload) {
    state.conversationLoader = true
    this.$Api(
      'get',
      `/admin/agents-list`,
      null,
      res => {
        payload.callback(res)
      },
      err => {
        state.conversationLoader = false
        console.log(err)
      }
    )
  },
  fetchUserContacts(state, payload) {
    state.contactsLoader = true
    this.$Api(
      'get',
      `whatsapp/accounts/${payload.whatapp_account}/conversations?page=${payload.page}`,
      null,
      res => {
        payload.callback(res)
        state.contactsLoader = false
      },
      err => {
        state.contactsLoader = false
        console.log(err)
      }
    )
  },
  addToArchive(state, payload) {
    state.contactsLoader = true
    this.$Api(
      'post',
      `whatsapp/accounts/${payload.whatapp_account}/conversations/${payload.userId}/archive-toggle`,
      null,
      res => {
        payload.callback(res)
        state.contactsLoader = false
      },
      err => {
        state.contactsLoader = false
        console.log(err)
      }
    )
  }
}
