// state
const state = () => ({
  loadingStatus: false,
  remindersLoadingStatus: false,
  statisticsData: null,
  timeTrackingData: null,
  branchesData: null,
  stagesTrackingData: null,
  stageStatusData: null,
  currentStageName: '',
  salesReportData: null,
  activitiesData: null,
  notesData: null,
  tasksData: null,
  remindersData: null
})

// getters
const getters = {
  loading(state) {
    return state.loadingStatus
  },
  statistics(state) {
    return state.statisticsData
  },
  trackData(state) {
    return state.timeTrackingData
  },
  branches(state) {
    return state.branchesData
  },
  stagesData(state) {
    return state.stagesTrackingData
  },
  salesReport(state) {
    return state.salesReportData
  },
  activities(state) {
    return state.activitiesData
  },
  notes(state) {
    return state.notesData
  },
  tasks(state) {
    return state.tasksData
  },
  reminders(state) {
    return state.remindersData
  },
  stageStatus(state) {
    return state.stageStatusData
  },
  currentStage(state) {
    return state.currentStageName
  }
}

// actions
const actions = {
  getDashboardData({ commit }, params) {
    commit('GET_DASHBOARD_DATA', params)
  },
  getTasksData({ commit }, params) {
    commit('GET_TASKS_DATA', params)
  },
  getRemindersData({ commit }, params) {
    commit('GET_REMINDERS_DATA', params)
  },
  setStageStatus({ commit }, params) {
    commit('SET_STAGE_STATUS', params)
  }
}

// mutations
const mutations = {
  GET_DASHBOARD_DATA(state, payload) {
    state.loadingStatus = true
    this.$Api('post', `/admin/panel/dashboard`, payload, res => {
      state.statisticsData = Object.entries(res.data.data.section_one).map(([key, value]) => ({
        name: value.name,
        count: value.count
      }))
      state.branchesData = Object.entries(res.data.data.section_four).map(([key, value]) => ({
        name: value.name,
        count: value.clients_count
      }))
      state.timeTrackingData = res.data.data?.section_five?.time_tracking
      state.stagesTrackingData = res.data.data?.section_five?.stages
      state.salesReportData = res.data.data.section_five
      state.activitiesData = res.data.data.section_three.logs.slice(-10)
      state.notesData = res.data.data.section_three.notes.slice(-10)
      state.loadingStatus = false
    })
  },
  GET_TASKS_DATA(state, payload = '') {
    state.loadingStatus = true
    this.$Api('get', `/admin/tasks/my-tasks${payload}`, null, res => {
      state.tasksData = res.data.data
      state.loadingStatus = false
    })
  },
  GET_REMINDERS_DATA(state, payload = '') {
    this.$Api('get', `/admin/profile${payload}`, null, res => {
      localStorage.setItem('userId', res.data.data.id)
      this.$Api('get', `/admin/reminders/users/${res.data.data.id}`, null, res => {
        state.remindersData = res.data.data
      })
    })
  },
  SET_STAGE_STATUS(state, payload = '') {
    state.currentStageName = payload
    state.stageStatusData = state.stagesTrackingData.filter(item => item.name === payload)
  }
}

export default {
  namespaced: true,
  state,
  getters,
  actions,
  mutations
}
