// state
const state = () => ({
  data: null,
  single: null,
  pagination: null,
  forms: null,
  fields: null,
  formFields: null,
  previewLead: null,
  selectedSubmissionData: null,
})

// getters
const getters = {
  allData(state) {
    return state.data
  },

  singleData(state) {
    return state.single
  },

  pagination(state) {
    return state.pagination
  },

  formsList(state) {
    return state.forms
  },

  leadsFields(state) {
    return state.fields
  },

  leadsFormFields(state) {
    return state.formFields
  },

  leadToPreview(state) {
    return state.previewLead
  },

  exportSubmission(state) {
    return state.files
  },

}

// actions
const actions = {
  list({ commit }, params) {
    commit('GET_LIST_DATA', params)
  },

  getSingle({ commit }, data) {
    commit('GET_SINGLE_DATA', data)
  },

  listForms({ commit }, params) {
    commit('GET_FORMS_LIST', params)
  },

  getLeadsFields({ commit }, params) {
    commit('GET_LEADS_FIELDS', params)
  },

  getLeadsFormFields({ commit }, params) {
    commit('GET_LEADS_FORM_FIELDS', params)
  },

  setPreviewLead({ commit }, data) {
    commit('SET_LEAD_TO_PREVIEW', data)
  },

  emptyPreviewLead({ commit }) {
    commit('EMPTY_LEAD_TO_PREVIEW')
  },

  exportSubmission({ commit }) {
    commit('EXPORT_FILES')
  },

  importSubmission({ commit }, data) {
    commit('IMPORT_FILES', data)
  }
}

// mutations
const mutations = {
  GET_LIST_DATA(state, params = '') {
    this.$Api('get', `/admin/leads${params}`, null, res => {
      state.data = res.data.data
      state.pagination = {
        meta: res.data.meta,
        links: res.data.links
      }
    })
  },

  GET_SINGLE_DATA(state, data) {
    if (data.path && data.path.includes('dashboard/leads')) {
      this.$Api('get', `/admin/leads/${data.id}`, null, res => {
        state.single = res.data.data
      })
    } else {
      this.$Api('get', `/admin/contacts/${data.id}`, null, res => {
        state.single = res.data.data
      })
    }
  },

  GET_FORMS_LIST(state, params) {
    this.$Api('get', `/admin/forms${params}`, null, res => {
      state.forms = res.data.data
    })
  },

  GET_LEADS_FIELDS(state, params = '') {
    this.$Api('get', `/admin/panel/field-setting${params}`, null, res => {
      state.fields = res.data.data[Object.keys(res.data.data)[0]]
    })
  },

  GET_LEADS_FORM_FIELDS(state, params = '') {
    this.$Api('get', `/admin/fields${params}`, null, res => {
      state.formFields = res.data.leads
    })
  },

  SET_LEAD_TO_PREVIEW(state, data) {
    this.$Api('get', `/admin/${data.userType}/${data.id}`, null, res => {
      state.previewLead = res.data.data
    })
  },

  EMPTY_LEAD_TO_PREVIEW(state) {
    state.previewLead = null
  },

  SELECT_SUBMISSION(state, submission) {
    state.selectedSubmissionData = submission
  },

  EXPORT_FILES() {
    this.$Api('get', `/admin/leads/excel/export`, null, res => {
      const csvData = res.data;

      // Create a Blob from the CSV data
      const blob = new Blob([csvData], { type: 'text/csv' });
      const url = URL.createObjectURL(blob);

      // Create a temporary link element
      const a = document.createElement('a');
      a.href = url;
      a.download = 'leads.csv';

      // Append the link to the document body
      document.body.appendChild(a);

      // Trigger the download by simulating a click
      a.click();

      // Clean up and remove the link
      document.body.removeChild(a);
      URL.revokeObjectURL(url);
    })
    
  },
  IMPORT_FILES(state, payload) {
    const formData = new FormData();
    formData.append('file', payload);
    this.$Api('post', `/admin/leads/excel/import`, formData, res => {
     console.log(res)
     payload.callback()
    })
  
  }
}

export default {
  namespaced: true,
  state,
  getters,
  actions,
  mutations
}
