export const state = () => ({
  notificationsList: [],
  notificationsListPage: [],
  pagination: {},
  unReadCount: 0
  // isEmailAssigned: false
})

export const getters = {
  notifications(state) {
    return state.notificationsList
  },
  allData(state) {
    return state.notificationsListPage
  },
  pagination(state) {
    return state.pagination
  },
  count(state) {
    return state.unReadCount
  }
}

export const actions = {
  // get all notifications
  async index({ commit }) {
    await this.$axios.get('/admin/notifications').then(res => {
      commit('LIST_NOTIFICATIONS', res.data.data)
      commit('SET_COUNT', res?.data?.meta?.unread_notifications_count || 0)
    })
  },
  // submit new notification to the list
  async workflow({ commit }, payload) {
    commit('workflow', payload)
  },
  async removeNotification({ commit }, payload) {
    commit('removeNotification', payload)
  },

  // get all statuses
  //  async statuses({ commit }, payload) {
  //   commit('statuses', payload)
  // },

  // push new notification to the list
  async pushNotification({ commit }, payload) {
    commit('PUSH_NOTIFICATION', payload)
  },
  list({ commit }, params) {
    commit('GET_LIST_DATA', params)
  },

  markNotificationAsRead({ commit }, params) {
    commit('MARK_NOTIFICATION_AS_READ', params)
  }
}

export const mutations = {
  // set notifications list
  LIST_NOTIFICATIONS(state, payload) {
    state.notificationsList = payload
  },

  SET_COUNT(state, payload) {
    state.unReadCount = payload
  },

  // push new notification to the top of list
  PUSH_NOTIFICATION(state, payload) {
    state.notificationsList.unshift(payload)
    state.unReadCount += 1
  },
  workflow($this, payload) {
    this.$Api('post', `/admin/workflows-notification/${payload.payload.get('id')}/status`, payload.payload, res => {
      if (res.data.message) {
        payload.call()
      }
    })
  },
  removeNotification($this, payload) {
    this.$Api('delete', `/admin/workflows-notification/${payload.payload.get('id')}/workflow`, payload.payload, res => {
      if (res.data.message) {
        payload.call()
      }
    })
  },
  GET_LIST_DATA(state, params = '') {
    this.$Api('get', `/admin/notifications${params}`, null, res => {
      state.notificationsListPage = res.data.data
      state.pagination = {
        meta: res.data.meta,
        links: res.data.links
      }
      state.unReadCount = res?.data?.meta?.unread_notifications_count || 0
    })
  },

  MARK_NOTIFICATION_AS_READ(state, params) {
    this.$Api(
      'post',
      `/admin/notifications/mark-as-read/${params.id}`,
      { _method: 'PUT' },
      () => {
        try {
          if (state.notificationsListPage.length > 0) {
            const index = state.notificationsListPage.findIndex(el => el.id === params.id)
            if (index >= 0) {
              state.notificationsListPage[index].read_at = new Date().toISOString()
            }
          }

          if (state.notificationsList.length > 0) {
            const index = state.notificationsList.findIndex(el => el.id === params.id)
            if (index >= 0) {
              state.notificationsList[index].read_at = new Date().toISOString()
            }
          }

          if (state.unReadCount > 0) {
            state.unReadCount -= 1
          }
        } catch (ex) {
          console.log('store-notifications:: ex:: ', ex)
        }
      },
      null,
      false,
      false
    )
  }
}
