// state
const state = () => ({
  loadingStatus: false,
  totalLeadsData: 0,
  totalBranchesData: null,
  totalProductsData: null,
  totalAgentsData: null,
  generalReportsData: null,

  timeTrackingLoadingStatus: false,
  timeTrackingData: null,

  stagesLoadingStatus: false,
  stagesTrackingData: null,

  currentStageName: '',
  stageStatusData: null
})

// getters
const getters = {
  loading(state) {
    return state.loadingStatus
  },
  totalLeads(state) {
    return state.totalLeadsData
  },
  totalBranches(state) {
    return state.totalBranchesData
  },
  totalProducts(state) {
    return state.totalProductsData
  },
  totalAgents(state) {
    return state.totalAgentsData
  },
  generalReports(state) {
    return state.generalReportsData
  },

  timeTrackingLoading(state) {
    return state.timeTrackingLoadingStatus
  },
  timeTracking(state) {
    return state.timeTrackingData
  },

  stagesLoading(state) {
    return state.stagesLoadingStatus
  },
  stagesData(state) {
    return state.stagesTrackingData
  },

  currentStage(state) {
    return state.currentStageName
  },
  stageStatus(state) {
    return state.stageStatusData
  }
}

// actions
const actions = {
  getGeneralReports({ commit }, params) {
    commit('GET_GENERAL_REPORTS', params)
  },
  getTimeTrackingData({ commit }, params) {
    commit('GET_TIME_TRACKING', params)
  },
  getStagesTrackingData({ commit }, params) {
    commit('GET_STAGES_TRACKING', params)
  },
  setStageStatus({ commit }, params) {
    commit('SET_STAGE_STATUS', params)
  }
}

// mutations
const mutations = {
  GET_GENERAL_REPORTS(state, payload = '') {
    state.loadingStatus = true
    this.$Api('get', `/admin/panel/general-report${payload}`, null, res => {
      console.log('general-report', res.data.data)
      state.totalLeadsData = res.data.data.total_leads
      state.totalBranchesData = res.data.data.total_branches
      state.totalProductsData = res.data.data.total_products
      state.totalAgentsData = res.data.data.total_agents
      state.loadingStatus = false
    })
  },

  GET_TIME_TRACKING(state, payload = '') {
    state.timeTrackingLoadingStatus = true
    this.$Api('get', `/admin/panel/general-report/time-tracking${payload}`, null, res => {
      state.timeTrackingData = res.data.data
      state.timeTrackingLoadingStatus = false
    })
  },

  GET_STAGES_TRACKING(state, payload = '') {
    state.stagesLoadingStatus = true
    this.$Api('get', `/admin/panel/general-report/stages-tracking${payload}`, null, res => {
      state.stagesTrackingData = res.data.data
      state.currentStageName = ''
      state.stagesLoadingStatus = false
    })
  },

  SET_STAGE_STATUS(state, payload = '') {
    state.currentStageName = payload
    state.stageStatusData = state.stagesTrackingData.filter(item => item.name === payload)
  }
}

export default {
  namespaced: true,
  state,
  getters,
  actions,
  mutations
}
