import Vue from 'vue'
export const strict = false

export const state = () => ({
  loader: false,
  data: null,
  myProfileData: null,
  myCompanyData: null
})

export const actions = {
  index(state, filter) {
    state.commit('index', filter)
  },
  put(state, payload) {
    if (payload.formdata) {
      const formData = new FormData()
      formData.append(payload.key, payload.value)

      state.commit('store', {
        id: payload.id,
        data: formData
      })
    } else {
      const formData = {}
      formData[payload.key] = payload.value

      state.commit('store', {
        id: payload.id,
        data: formData
      })
    }
  },
  updatePassword($this, payload) {
    $this.commit('updatePassword', payload)
  },
  myProfile($this, payload) {
    $this.commit('myProfile', payload)
  },
  updateProfile($this, payload) {
    // append key called _method with value PUT to payload.data object
    payload.data._method = 'PUT'
    let data = new FormData()
    let payloadData = payload.data
    Object.keys(payloadData).forEach(key => {
      if (payloadData[key]) {
        if (key != 'profile') {
          data.append(key, payloadData[key])
        }
      }
    })

    if (payloadData.profile && payloadData.profile.length) {
      payloadData.profile.forEach((file, i) => {
        if (i < 1) {
          data.append(`profile`, file)
        } else {
          data.append(`profile[${i}]`, file)
        }
      })
    }

    $this.commit('updateProfile', {
      data: data,
      callback: payload.callback
    })
  },
  updateCompany($this, payload) {
    $this.commit('updateCompany', {
      data: data,
      callback: payload.callback
    })
  },
  companyProfile($this, payload) {
    $this.commit('companyProfile', payload)
  }
}

export const mutations = {
  async index(state) {
    state.loader = true
    try {
      await this.$axios.get(`/admin/settings`).then(res => {
        state.data = res.data.data
        state.loader = true
        if (res.data.message) {
          this.$alert('success', res.data.message)
        }
      })
    } catch (error) {
      state.loader = false
      this.$alert('error', error.message)
    } finally {
      state.loader = false
    }
  },
  async store(state, payload) {
    state.loader = true
    return await this.$axios
      .put(`admin/settings/${payload.id}`, payload.data)
      .then(res => {
        state.loader = false
        if (res.data.message) {
          this.$alert('success', res.data.message)
        }
      })
      .catch(err => {
        console.log(err)
        this.$alert('error', error.data.message)
        state.loader = false
      })
      .finally(state => {
        state.loader = false
      })
  },
  async updatePassword($this, payload) {
    this.$Api('put', `admin/change-password`, payload.data, () => {
      payload.callback()
    })
  },
  async myProfile(state) {
    state.loader = true
    try {
      await this.$axios.get(`/admin/profile`).then(res => {
        state.myProfileData = res.data.data
        state.loader = true
        if (res.data.message) {
          this.$alert('success', res.data.message)
        }
      })
    } catch (error) {
      state.loader = false
      this.$alert('error', error.message)
    } finally {
      state.loader = false
    }
  },
  async companyProfile(state) {
    state.loader = true
    try {
      await this.$axios.get(`/admin/settings`).then(res => {
        state.myCompanyData = res.data.data
        state.loader = true
        if (res.data.message) {
          this.$alert('success', res.data.message)
        }
      })
    } catch (error) {
      state.loader = false
      this.$alert('error', error.message)
    } finally {
      state.loader = false
    }
  },
  async updateProfile($this, payload) {
    this.$Api('post', `/admin/profile`, payload.data, () => {
      payload.callback()
    })
  },
  async updateCompany($this, payload) {
    console.log(payload)
    this.$Api('post', `/admin/settings/${payload.id}`, payload.data, () => {
      payload.callback()
    })
  }
}
