import Vue from 'vue';
export const state = () => ({
  emailTemplateModal: false,
  emailContentModal: false,
  whatsappTemplateModal: false,
  whatsappContentModal: false,
  statusId: null,
  form: {
    subject: '',
    content: '',
  }
});

export const mutations = {
  SET_EMAIL_TEMPLATE_MODAL (state, { show, statusId }) {
    state.emailTemplateModal = show;
    state.statusId = statusId;
  },
  SET_EMAIL_CONTENT_MODAL (state, {
    show, statusId
  }) {
    state.emailContentModal = show;
    state.statusId = statusId;
  },
  SET_WHATSAPP_TEMPLATE_MODAL (state, { show, statusId }) {
    state.whatsappTemplateModal = show;
    state.statusId = statusId;
  },
  SET_WHATSAPP_CONTENT_MODAL (state, {
    show, statusId
  }) {
    state.whatsappContentModal = show;
    state.statusId = statusId;
  },
  CLOSE_ALL_MODALS (state) {
    state.emailTemplateModal = false;
    state.emailContentModal = false;
    state.whatsappTemplateModal = false;
    state.whatsappContentModal = false;
    state.statusId = null;
    state.form = {
      subject: '',
      content: '',
    };
  }
};

export const actions = {
  async assignNotification ({ state, commit }, payload) {
    const formData = new FormData();
    for (let key in payload) {
      if (typeof payload[ key ] === 'object') {
        for (let objKey in payload[ key ]) {
          formData.append(`${ key }[${ objKey }]`, payload[ key ][ objKey ]);
        }
      }
      else {
        formData.append(key, payload[ key ]);
      }
    }
    try {
      const { data } = await this.$axios.post(`admin/workflows-notification/${ state.statusId }/status`, formData);
      commit('CLOSE_ALL_MODALS');
      Vue.$toast.success('Notification assigned successfully');
    }
    catch (e) {
      Vue.$toast.error(e.response.data.message);
    }
    return data;
  }
};


export const getters = {
  emailTemplateModal: state => state.emailTemplateModal,
  emailContentModal: state => state.emailContentModal,
  whatsappTemplateModal: state => state.whatsappTemplateModal,
  whatsappContentModal: state => state.whatsappContentModal,
};