export const state = () => ({
  plansList: [],
  myPlan: null
});

export const getters = {
  plans: state => state.plansList,
  myPlan: state => state.myPlan,
  features: state => {
    // Get the keys of the features from the first plan
    const featuresKeys = state.plansList?.length && Object.keys(state.plansList[ 0 ]?.features);

    // Reduce the plansList array to a single object that groups the features by their keys
    return state.plansList?.reduce((acc, plan) => {
      featuresKeys.forEach(key => {
        // Initialize the accumulator for the current key if it doesn't exist
        if (!acc[ key ]) {
          acc[ key ] = {};
        }

        // Loop over the features for the current key
        plan.features[ key ].forEach(feature => {
          // Destructure the name from the feature
          const { name } = feature;

          // Initialize the accumulator for the current feature name if it doesn't exist
          if (!acc[ key ][ name ]) {
            acc[ key ][ name ] = [];
          }

          // Push the feature to the accumulator
          acc[ key ][ name ].push(feature);
        });
      });

      // Return the accumulator
      return acc;
    }, {});
  }
};

export const actions = {
  async getPlans ({ commit, state }) {
    if (state.plansList.length) return;
    const { data } = await this.$axios('admin/plans');
    commit('SET_PLANS', data);
  },

  async getMyPlan ({ commit, state }) {
    if (state.myPlan) return;
    const { data } = await this.$axios('admin/active-subscription');
    commit('SET_PLAN', data.data);
  },


};

export const mutations = {
  SET_PLANS (state, plans) {
    state.plansList = plans;
  },

  SET_PLAN (state, plan) {
    state.myPlan = plan;
  }
};
