import Vue from 'vue';

export const state = () => ({
  loader: false,
  data: null,
  singleTask: 'test',
})


export const actions = {
  single(state, projectId) {
    state.commit('show', projectId);
  },
  addTask(state, payload) {
    state.commit('store', payload);
  },
  sendComment(state, payload) {
    state.commit('storeComment', payload);
  },
  updateTaskData(state, payload) {
    state.commit('put', payload);
  },
}

export const mutations = {
  async show(state, id) {
    state.loader = true;
    try {
      await this.$axios.get(`/admin/tasks/${id}`).then((res) => {
        state.singleTask = res.data.data;
        if (res.data.message) {
          this.$alert('success', res.data.message);
        }
      });
    } catch (error) {
      state.loader = false;
      this.$alert('error', err.data.message);
    } finally {
      state.loader = false;
    }
  },
  async store(state, payload) {
    state.loader = true;
    return await this.$axios.post(`/admin/tasks`, payload).then(res => {
      if (res.data.message) {
        this.$alert('success', res.data.message);
      }
    }).finally((state) => {
      state.loader = false;
    }).catch((err) => {
      state.loader = false;
      this.$alert('error', err.data.message);
      console.log(err);
    });
  },

  async storeComment(state, payload) {
    state.loader = true;
    return await this.$axios.post(`/admin/tasks/${payload.id}/comments`, {
      comment: payload.comment
    }).then(res => {
      if (res.data.message) {
        this.$alert('success', res.data.message);
      }
      console.log('my Route', this.$route.params.taskID)
    }).finally((state) => {
      state.loader = false;
    }).catch((err) => {
      state.loader = false;
      this.$alert('error', err.data.message);
      console.log(err);
    });
  },

  async put(state, payload) {
    state.loader = true;
    return await this.$axios.put(`/admin/tasks${payload.id}`, payload).then(res => {
      if (res.data.message) {
        this.$alert('success', res.data.message);
      }
    }).finally((state) => {
      state.loader = false;
    }).catch((err) => {
      state.loader = false;
      this.$alert('error', err.data.message);
      console.log(err);
    });
  },

  async delete(state, id) {
    state.loader = true;
    return await this.$axios.delete(`/admin/tasks/${id}`).then(res => {
      if (res.data.message) {
        this.$alert('success', res.data.message);
      }
      this.$store.dispatch('projects/fetchProject', this.$route.params.projectID);

    }).finally((state) => {
      state.loader = false;
    }).catch((err) => {
      state.loader = false;
      this.$alert('error', err.data.message);
      console.log(err);
    });
  },

  async complete(state, id) {
    state.loader = true;
    return await this.$axios.post(`/admin/tasks/${id}/complete`).then(res => {
      if (res.data.message) {
        this.$alert('success', res.data.message);
      }
    }).finally((state) => {
      state.loader = false;
    }).catch((err) => {
      state.loader = false;
      this.$alert(err.data.message, "error");
    });
  },
}
